@@ -48,6 +48,9 @@
 .ddg.init.iotrace <- function () {
   #print ("Initializing io tracing")
   
+  # Find out what packages are installed
+  .ddg.set("ddg.installed.package.names", utils::installed.packages()[,1])
+  
   # Store the starting graphics device.
   .ddg.set("ddg.open.devices", vector())
   
@@ -94,8 +97,6 @@
   # Note that we need to use the rdt::: notation for the functions for 
   # trace to call so that it can find those functions without making them 
   # publicly available in the namespace.
-  # ggplot2 functions are traced individually because the package name needs to 
-  # be included.
   
   trace.oneOutput <- 
     function (f) {
@@ -106,12 +107,6 @@
                               type="message"))
     } 
   lapply(.ddg.get("ddg.file.write.functions.df")$function.names, trace.oneOutput)
-  utils::capture.output(
-    utils::capture.output(trace (ggplot2::ggplot, 
-            function () .ddg.trace.output (), 
-                                 print=FALSE), 
-                          type="message"))
-  
   trace.oneInput <- 
     function (f) {
       utils::capture.output(
@@ -131,11 +126,6 @@
                               type="message"))
     } 
   lapply(.ddg.get("ddg.file.close.functions.df")$function.names, trace.oneClose)
-  utils::capture.output(
-    utils::capture.output(trace (ggplot2::ggsave, 
-            function () .ddg.trace.close (), 
-                                 print=FALSE), 
-                          type="message"))
   
   #print ("Tracing graphics open")
   # trace (grDevices::pdf, rdt:::.ddg.trace.graphics.open, print=TRUE)
@@ -166,6 +156,21 @@
             function () .ddg.trace.graphics.close (), 
                                  print=FALSE), 
                           type="message"))
+                          
+  # Trace ggplot2 functions if ggplot2 is installed.
+  if ("ggplot2" %in% .ddg.get("ddg.installed.package.names")) {
+  	utils::capture.output(
+    	utils::capture.output(trace (ggplot2::ggplot, 
+            function () .ddg.trace.output (), 
+                                 print=FALSE), 
+                          type="message"))
+    utils::capture.output(
+      utils::capture.output(trace (ggplot2::ggsave, 
+            function () .ddg.trace.close (), 
+                                 print=FALSE), 
+                          type="message"))
+  }          
+
   #print ("Done initializing IO tracing")
 }
 
@@ -192,8 +197,10 @@
                          type="message")
   utils::capture.output (untrace(grDevices::dev.off), type="message")
   
-  utils::capture.output (untrace(ggplot2::ggplot), type="message")
-  utils::capture.output (untrace(ggplot2::ggsave), type="message")
+  if ("ggplot2" %in% .ddg.get("ddg.installed.package.names")) {
+    utils::capture.output (untrace(ggplot2::ggplot), type="message")
+    utils::capture.output (untrace(ggplot2::ggsave), type="message")
+  }
 }
 
 ################### Helper functions ######################3
@@ -355,13 +362,17 @@
   
   # Get the frame corresponding to the output function being traced
   frame.number <- .ddg.get.traced.function.frame.number()
+  #print ("Got frame number")
   
   # Filter out some calls based on what function called the input function.
   # The is.symbol test is used because it is possible that the caller is a 
   # closure and thus does not have a name.
   input.caller <- sys.call (frame.number - 1)[[1]]
+  #print ("Got input.caller")
   if (is.symbol (input.caller)) {
+    #print ("input.caller is symbol")
     input.caller.name <- as.character(input.caller)
+    #print ("got input.caller.name")
     
     # Check if the function that called the input function is any ddg function.
     # If it is, ignore this call.  .ddg.load.history is an example of a 
@@ -374,6 +385,7 @@
     
   }
   
+  #print ("Checking for library, loadNamespace, .ddg.json.string")
   # Don't collect provenance when loading library packages.  Also, when writing out the
   # json, files get read in order to identify package version numbers.
   if (.ddg.inside.call.to ("library") || 
@@ -382,15 +394,26 @@
     return()
   }
   
+  # Get the name of the input function
+  call <- sys.call (frame.number)
+  if (typeof(call[[1]]) == "closure") {
+    #print (sys.calls())
+    return()
+  }
+  fname <- as.character(call[[1]])
+  
+  # Remove the package name if present
+  if (!is.symbol (fname) && length(fname > 1)) {
+    fname <- fname[length(fname)]
+  }
+  
+  #print (paste ("Input function traced: ", fname))
+  
+  #print ("Checking for source")
   # If we are sourcing a script, record the file as a sourced script instead of
   # as an input file.
-  if (.ddg.inside.call.to ("source")) {
-    if (.ddg.inside.call.to ("readLines")) {
-      # The information was recorded when the call to source was found.
-      return()
-    }
-    source.call <- .ddg.get.call.to ("source")
-    frame.number <- .ddg.get.frame.number.for.func ("source")
+  if (fname == "source") {
+    #print ("Tracing source")
     sourced.file.name <- eval (as.symbol ("file"), envir=sys.frame(frame.number))
     
     if (.ddg.is.connection(sourced.file.name)) {
@@ -406,17 +429,17 @@
     return ()
   }
   
-  # Get the name of the input function
-  call <- sys.call (frame.number)
-  fname <- as.character(call[[1]])
-  
-  # Remove the package name if present
-  if (!is.symbol (fname) && length(fname > 1)) {
-    fname <- fname[length(fname)]
-  }
-  
-  #print (paste ("Input function traced: ", fname))
+  if (.ddg.inside.call.to ("source")) {
+    #print("Reading sourced file")
+    source.frame.number <- .ddg.get.frame.number.for.func ("source")
+    if (source.frame.number == frame.number - 1) {
+      # This read call is what is actually reading the sourced file.
+      # The information was recorded when the call to source was found.
+      return()
+    }
+  } 
   
+  #print ("Getting ready to save input info")
   # Get the name of the file parameter for the input function
   file.read.functions <- .ddg.get ("ddg.file.read.functions.df")
   file.param.name <- 
@@ -425,12 +448,15 @@
   
   # Get the value of the file parameter  
   input.file.name <- eval (as.symbol(file.param.name), envir = sys.frame(frame.number))
+  #print (paste ("type of input.file.name is ", .ddg.get.val.type.string(input.file.name)))
   #print (paste ("input.file.name =", input.file.name))
 
   # Save the file name so the file node can be created when the statement is complete.
   # we do not want to create the nodes because the procedure node to connect to does not
-  # exist yet.
-  .ddg.add.input.file (input.file.name)
+  # exist yet.  If it is a raw vector rather than a file name, do not save it.
+  if (!is.raw(input.file.name)) {
+    .ddg.add.input.file (input.file.name)
+  }
 }
 
 
@@ -730,8 +756,16 @@
   datasets <- .ddg.get ("ddg.output.data")
   sapply (datasets, 
           function (dataset) {
-            .ddg.data.node ("Data", dataset, eval(as.name(dataset), envir=globalenv()), environmentName(globalenv()))
-            .ddg.lastproc2data (dataset)    
+            #print (paste ("Handling dataset", dataset))
+            # Only create the node if we can find the dataset in memory.  It might not be in the 
+            # global environment.
+             tryCatch (
+                 {
+                   .ddg.data.node ("Data", dataset, eval(as.name(dataset), envir=globalenv()), environmentName(globalenv()))
+                   .ddg.lastproc2data (dataset)
+                 },
+                 error = function(e) {}
+              )
           }
   )
 
@@ -1125,12 +1159,26 @@
   # Get the frame corresponding to the graphics function being traced
   frame.number <- .ddg.get.traced.function.frame.number()
   
-  # Get the name of the graphics function
   call <- sys.call (frame.number)
+  
+  # Normally, we would expect to be tracing a function that we have asked
+  # to trace.  However, if this inside an R Markdown file that the user
+  # is running from console mode, we end up getting a closure instead.
+  # In that case, the plot is going into the on-screen R Markdown display,
+  # We will capture the output the same way as if it was going to an 
+  # X11 window or something similar.
+  if (rlang::is_closure (call[[1]])) {
+    .ddg.set("ddg.no.graphics.file", TRUE)
+    .ddg.set("ddg.last.graphics.file", "")
+    .ddg.set ("ddg.add.device.output", TRUE)
+    return()
+  }
+  
+  # Get the name of the graphics function
   fname <- as.character(call[[1]])
   
   # Remove the package name if present
-  if (length(fname > 1)) {
+  if (length(fname) > 1) {
     fname <- fname[length(fname)]
   }
   #print(paste (".ddg.trace.graphics.open: fname =", fname))
@@ -1151,8 +1199,10 @@
     # Get the value of the file parameter  
     file <- eval (as.symbol(file.param.name), envir = sys.frame(frame.number))
     #print(paste (".ddg.trace.graphics.open: file =", file))
-    .ddg.set("ddg.no.graphics.file", FALSE)
-    .ddg.set ("ddg.last.graphics.file", file)
+    if (!is.null(file)) {
+      .ddg.set("ddg.no.graphics.file", FALSE)
+      .ddg.set ("ddg.last.graphics.file", file)
+    }
   }
   
   # Set the flag to tell .ddg.add.graphics.device.node that it has work to do 
@@ -1179,7 +1229,7 @@
   #              names(grDevices::dev.list()), collapse=", "))
   #print (paste ("dev.cur =", grDevices::dev.cur()))
   
-  if (!names(grDevices::dev.cur()) %in% c("RStudioGD", "quartz", "windows")) {
+  if (!names(grDevices::dev.cur()) %in% c("RStudioGD", "quartz", "quartz_off_screen", "windows")) {
     # Record the binding between the current device and the graphics file, if
     # a file is being used.
     if (.ddg.is.set ("ddg.last.graphics.file") && 
