@@ -41,8 +41,15 @@
   
   # Generate the formatted output.  Remember where it is so that it
   # can be connected to the ddg.
-  markdown.output <- rmarkdown::render(r.script.path, quiet=TRUE)
-  .ddg.set("ddg.markdown.output", markdown.output)
+  tryCatch(
+  {
+    markdown.output <- rmarkdown::render(r.script.path, quiet=TRUE)
+    .ddg.set("ddg.markdown.output", markdown.output)
+  },
+  error=function(x)
+  {
+    print(x)
+  })
   
   #moves file to ddg directory
   file.rename(from = r.file, to = output.path)
